@@ -1,4 +1,4 @@
-from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Type, Union, IO
+from typing import IO, Any, Callable, Dict, List, Optional, Sequence, Tuple, Type, Union
 
 Dict, Type
 
@@ -15,8 +15,8 @@ import time
 import traceback
 
 import colorama
-import unidecode
 import tabulate
+import unidecode
 
 ConfigValue = Union[None, bool, str]
 FileObj = IO[str]
@@ -55,7 +55,7 @@ def setup(
     quiet: bool = False,
     color: str = "auto",
     title: str = "auto",
-    timestamp: bool = False
+    timestamp: bool = False,
 ) -> None:
     """ Configure behavior of message functions.
 
@@ -78,28 +78,32 @@ def _setup(**kwargs: ConfigValue) -> None:
 class Color:
     """Represent an ANSI escape sequence """
 
-    def __init__(self, code: str):
+    def __init__(self, name: str, code: str):
+        self.name = name
         self.code = code
 
+    def __repr__(self) -> str:
+        return f"Color({self.name})"
+
 
 # fmt: off
-reset     = Color(colorama.Style.RESET_ALL)
-bold      = Color(colorama.Style.BRIGHT)
-faint     = Color(colorama.Style.DIM)
+reset     = Color("reset", colorama.Style.RESET_ALL)
+bold      = Color("bold", colorama.Style.BRIGHT)
+faint     = Color("dim", colorama.Style.DIM)
 # for some reason those are not in colorama
-standout  = Color('\x1b[3m')
-underline = Color('\x1b[4m')
-blink     = Color('\x1b[5m')
-overline  = Color('\x1b[6m')
+standout  = Color("standout", '\x1b[3m')
+underline = Color("underline", '\x1b[4m')
+blink     = Color("blink", '\x1b[5m')
+overline  = Color("overline", '\x1b[6m')
 
-black   = Color(colorama.Fore.BLACK)
-red     = Color(colorama.Fore.RED)
-green   = Color(colorama.Fore.GREEN)
-yellow  = Color(colorama.Fore.YELLOW)
-blue    = Color(colorama.Fore.BLUE)
-magenta = Color(colorama.Fore.MAGENTA)
-cyan    = Color(colorama.Fore.CYAN)
-white   = Color(colorama.Fore.WHITE)
+black   = Color("black", colorama.Fore.BLACK)
+red     = Color("red", colorama.Fore.RED)
+green   = Color("green", colorama.Fore.GREEN)
+yellow  = Color("yellow", colorama.Fore.YELLOW)
+blue    = Color("blue", colorama.Fore.BLUE)
+magenta = Color("magenta", colorama.Fore.MAGENTA)
+cyan    = Color("cyan", colorama.Fore.CYAN)
+white   = Color("white", colorama.Fore.WHITE)
 
 # backward compatibility:
 brown = yellow      # used by ui.warning
@@ -131,6 +135,9 @@ class UnicodeSequence:
     def tuple(self) -> Tuple[Token, ...]:
         return (reset, self.color, self.as_string, reset)
 
+    def __repr__(self) -> str:
+        return f"UnicodeSequence({repr(self.color)},{self.as_string})"
+
 
 ellipsis = UnicodeSequence(reset, "…", "...")
 check = UnicodeSequence(green, "✓", "ok")
@@ -144,6 +151,9 @@ class Symbol(UnicodeSequence):
     def tuple(self) -> Tuple[Token, ...]:
         return (self.as_string,)
 
+    def __repr__(self) -> str:
+        return f"Symbol({self.as_string})"
+
 
 def using_colorama() -> bool:
     if os.name == "nt":
@@ -247,7 +257,7 @@ def message(
     end: str = "\n",
     sep: str = " ",
     fileobj: FileObj = sys.stdout,
-    update_title: bool = False
+    update_title: bool = False,
 ) -> None:
     """ Helper method for error, warning, info, debug
 
@@ -399,17 +409,31 @@ def tabs(num: int) -> str:
 def info_table(
     data: Any, *, headers: Union[str, Sequence[str]] = (), fileobj: FileObj = sys.stdout
 ) -> None:
-    colored_data = list()
-    plain_data = list()
-    for row in data:
-        colored_row = list()
-        plain_row = list()
-        for item in row:
-            colored_str, plain_str = process_tokens(item, end="")
-            colored_row.append(colored_str)
-            plain_row.append(plain_str)
-        colored_data.append(colored_row)
-        plain_data.append(plain_row)
+    if headers == "keys":
+        colored_data: Any = dict()
+        plain_data: Any = dict()
+        for key, sequence in data.items():
+            colored_sequence = list()
+            plain_sequence = list()
+            for item in sequence:
+                colored_str, plain_str = process_tokens(item, end="")
+                colored_sequence.append(colored_str)
+                plain_sequence.append(plain_str)
+            colored_key, plain_key = process_tokens(key, end="")
+            colored_data[colored_key] = colored_sequence
+            plain_data[plain_key] = plain_sequence
+    else:
+        colored_data = list()
+        plain_data = list()
+        for row in data:
+            colored_row = list()
+            plain_row = list()
+            for item in row:
+                colored_str, plain_str = process_tokens(item, end="")
+                colored_row.append(colored_str)
+                plain_row.append(plain_str)
+            colored_data.append(colored_row)
+            plain_data.append(plain_row)
     if config_color(fileobj):
         data_for_tabulate = colored_data
     else:
@@ -492,7 +516,7 @@ def ask_choice(
     *prompt: Token,
     choices: List[Any],
     func_desc: Optional[FuncDesc] = None,
-    sort: Optional[bool] = True
+    sort: Optional[bool] = True,
 ) -> Any:
     """Ask the user to choose from a list of choices.
 
